@@ -1,6 +1,6 @@
 /* query-druid.c
  *
- * Copyright (C) 2004 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,6 +20,7 @@
 
 #include "query-druid.h"
 #include <libgnomedb/libgnomedb.h>
+#include <libgda/libgda.h>
 #include "workspace-page.h"
 #include "query-fields-editor.h"
 
@@ -30,8 +31,8 @@ static void query_druid_dispose (GObject   * object);
 
 struct _QueryDruidPriv
 {
-	GnomeDbDict      *dict;
-	GnomeDbQuery     *build_query;
+	GdaDict      *dict;
+	GdaQuery     *build_query;
 	
 	/* druid pages */
 	GtkWidget   *d_start;
@@ -117,19 +118,19 @@ static void query_druid_initialize (QueryDruid *mgsel);
 static void object_weak_notify (QueryDruid *mgsel, GObject *obj);
 /**
  * query_druid_new
- * @dict: a #GnomeDbDict object
+ * @dict: a #GdaDict object
  *
  * Creates a new #QueryDruid widget.
  *
  * Returns: the new widget
  */
 GtkWidget *
-query_druid_new (GnomeDbDict *dict)
+query_druid_new (GdaDict *dict)
 {
 	GObject    *obj;
 	QueryDruid *qdruid;
 
-	g_return_val_if_fail (dict && IS_GNOME_DB_DICT (dict), NULL);
+	g_return_val_if_fail (dict && GDA_IS_DICT (dict), NULL);
 		
 	obj = g_object_new (QUERY_DRUID_TYPE, NULL);
 	qdruid = QUERY_DRUID (obj);
@@ -148,12 +149,12 @@ static void
 object_weak_notify (QueryDruid *qdruid, GObject *obj)
 {
 	if (obj == (GObject*) qdruid->priv->dict)
-		/* Tell that we don't need to weak unref the GnomeDbDict */
+		/* Tell that we don't need to weak unref the GdaDict */
 		qdruid->priv->dict = NULL;
 }
 
-static void build_query_fields_changed (GnomeDbQuery *query, GnomeDbQfield *field, QueryDruid *qdruid);
-static void build_query_fields_order_changed (GnomeDbQuery *query, QueryDruid *qdruid);
+static void build_query_fields_changed (GdaQuery *query, GdaQueryField *field, QueryDruid *qdruid);
+static void build_query_fields_order_changed (GdaQuery *query, QueryDruid *qdruid);
 
 static void
 query_druid_dispose (GObject *object)
@@ -174,7 +175,7 @@ query_druid_dispose (GObject *object)
 			qdruid->priv->build_query = NULL;
 		}
 
-		/* Weak unref the GnomeDbDict if necessary */
+		/* Weak unref the GdaDict if necessary */
 		if (qdruid->priv->dict)
 			g_object_weak_unref (G_OBJECT (qdruid->priv->dict),
 					     (GWeakNotify) object_weak_notify, qdruid);
@@ -211,8 +212,8 @@ query_druid_initialize (QueryDruid *qdruid)
 	gtk_container_set_border_width (GTK_CONTAINER (qdruid), 4);
 
 	/* query which is built during the druid usage */
-	qdruid->priv->build_query = GNOME_DB_QUERY (gnome_db_query_new (qdruid->priv->dict));
-	gnome_db_query_set_query_type (qdruid->priv->build_query, GNOME_DB_QUERY_TYPE_SELECT);
+	qdruid->priv->build_query = GDA_QUERY (gda_query_new (qdruid->priv->dict));
+	gda_query_set_query_type (qdruid->priv->build_query, GDA_QUERY_TYPE_SELECT);
 
 	g_signal_connect (G_OBJECT (qdruid->priv->build_query), "field_added",
 			  G_CALLBACK (build_query_fields_changed), qdruid);
@@ -238,27 +239,27 @@ query_druid_initialize (QueryDruid *qdruid)
 }
 
 static void
-build_query_fields_changed (GnomeDbQuery *query, GnomeDbQfield *field, QueryDruid *qdruid)
+build_query_fields_changed (GdaQuery *query, GdaQueryField *field, QueryDruid *qdruid)
 {
 	build_query_fields_order_changed (query, qdruid);
 }
 
 static void
-build_query_fields_order_changed (GnomeDbQuery *query, QueryDruid *qdruid)
+build_query_fields_order_changed (GdaQuery *query, QueryDruid *qdruid)
 {
 	/* compute up and down status in the fields selection page */
-	GnomeDbField *selfield;
+	GdaEntityField *selfield;
 	gboolean canup = FALSE, candn = FALSE;
 
-	selfield = (GnomeDbField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
-	if (selfield && IS_GNOME_DB_FIELD (selfield)) {
-		GSList *fields = gnome_db_entity_get_fields (GNOME_DB_ENTITY (qdruid->priv->build_query));
+	selfield = (GdaEntityField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
+	if (selfield && GDA_IS_ENTITY_FIELD (selfield)) {
+		GSList *fields = gda_entity_get_fields (GDA_ENTITY (qdruid->priv->build_query));
 		GSList *last = g_slist_last (fields);
 		candn = TRUE;
 		if (last && (last->data == (gpointer) selfield))
 			candn = FALSE;
 		g_slist_free (fields);
-		canup = gnome_db_entity_get_field_index (GNOME_DB_ENTITY (qdruid->priv->build_query), selfield) != 0;
+		canup = gda_entity_get_field_index (GDA_ENTITY (qdruid->priv->build_query), selfield) != 0;
 
 		gtk_widget_set_sensitive (qdruid->priv->field_up_button, canup);
 		gtk_widget_set_sensitive (qdruid->priv->field_dn_button, candn);
@@ -324,7 +325,7 @@ make_query_attributes_page (QueryDruid *qdruid)
 	table = gtk_table_new (2, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 2);
 	gtk_widget_show (table);
-	gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 	
 	wid = gtk_label_new (_("Name:"));
 	gtk_widget_show (wid);
@@ -377,17 +378,17 @@ make_query_attributes_page (QueryDruid *qdruid)
 	gtk_widget_show (rb);
 	gtk_table_attach (GTK_TABLE (wid), rb, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
 	rb_group2 = gtk_radio_button_get_group (GTK_RADIO_BUTTON (rb));
-	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GNOME_DB_QUERY_TYPE_SELECT));
+	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GDA_QUERY_TYPE_SELECT));
 	g_signal_connect (G_OBJECT (rb), "toggled", G_CALLBACK (query_type_rb_toggled_cb), qdruid);
 	g_object_set_data (G_OBJECT (qdruid->priv->d_query_type), "query_type_1", 
-			   GINT_TO_POINTER (GNOME_DB_QUERY_TYPE_SELECT));
+			   GINT_TO_POINTER (GDA_QUERY_TYPE_SELECT));
 
 	rb = gtk_radio_button_new_with_mnemonic (NULL, _("INSERT query"));
 	gtk_widget_show (rb);
 	gtk_table_attach (GTK_TABLE (wid), rb, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (rb), rb_group2);
 	rb_group2 = gtk_radio_button_get_group (GTK_RADIO_BUTTON (rb));
-	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GNOME_DB_QUERY_TYPE_INSERT));
+	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GDA_QUERY_TYPE_INSERT));
 	g_signal_connect (G_OBJECT (rb), "toggled", G_CALLBACK (query_type_rb_toggled_cb), qdruid);
 
 	rb = gtk_radio_button_new_with_mnemonic (NULL, _("UPDATE query"));
@@ -395,7 +396,7 @@ make_query_attributes_page (QueryDruid *qdruid)
 	gtk_table_attach (GTK_TABLE (wid), rb, 1, 2, 2, 3, GTK_FILL, 0, 0, 0);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (rb), rb_group2);
 	rb_group2 = gtk_radio_button_get_group (GTK_RADIO_BUTTON (rb));
-	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GNOME_DB_QUERY_TYPE_UPDATE));
+	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GDA_QUERY_TYPE_UPDATE));
 	g_signal_connect (G_OBJECT (rb), "toggled", G_CALLBACK (query_type_rb_toggled_cb), qdruid);
 
 	rb = gtk_radio_button_new_with_mnemonic (NULL, _("DELETE query"));
@@ -403,7 +404,7 @@ make_query_attributes_page (QueryDruid *qdruid)
 	gtk_table_attach (GTK_TABLE (wid), rb, 1, 2, 3, 4, GTK_FILL, 0, 0, 0);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (rb), rb_group2);
 	rb_group2 = gtk_radio_button_get_group (GTK_RADIO_BUTTON (rb));
-	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GNOME_DB_QUERY_TYPE_DELETE));
+	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GDA_QUERY_TYPE_DELETE));
 	g_signal_connect (G_OBJECT (rb), "toggled", G_CALLBACK (query_type_rb_toggled_cb), qdruid);
 
 	rb = gtk_radio_button_new_with_mnemonic (NULL, _("Aggreation query (union, intersect or except)"));
@@ -411,7 +412,7 @@ make_query_attributes_page (QueryDruid *qdruid)
 	gtk_table_attach (GTK_TABLE (wid), rb, 1, 2, 4, 5, GTK_FILL, 0, 0, 0);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (rb), rb_group2);
 	rb_group2 = gtk_radio_button_get_group (GTK_RADIO_BUTTON (rb));
-	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GNOME_DB_QUERY_TYPE_UNION));
+	g_object_set_data (G_OBJECT (rb), "action", GINT_TO_POINTER (GDA_QUERY_TYPE_UNION));
 	g_signal_connect (G_OBJECT (rb), "toggled", G_CALLBACK (query_type_rb_toggled_cb), qdruid);
 
 	rb = gtk_radio_button_new_with_mnemonic (NULL, _("SQL query (of any type)"));
@@ -424,7 +425,7 @@ make_query_attributes_page (QueryDruid *qdruid)
 
 	/* default action */
 	g_object_set_data (G_OBJECT (qdruid->priv->d_query_type), "query_type", 
-			   GINT_TO_POINTER (GNOME_DB_QUERY_TYPE_SELECT));
+			   GINT_TO_POINTER (GDA_QUERY_TYPE_SELECT));
 }
 static void
 query_type_rb_toggled_cb (GtkToggleButton *btn, QueryDruid *qdruid)
@@ -449,7 +450,7 @@ query_type_rb_toggled_cb (GtkToggleButton *btn, QueryDruid *qdruid)
 	default:
 		g_object_set_data (G_OBJECT (qdruid->priv->d_query_type), "query_type_1", GINT_TO_POINTER (action));
 		g_object_set_data (G_OBJECT (qdruid->priv->d_query_type), "query_type", GINT_TO_POINTER (action));
-		gnome_db_query_set_query_type (qdruid->priv->build_query, action);
+		gda_query_set_query_type (qdruid->priv->build_query, action);
 		g_print ("Query type set to %d\n", action);
 		break;
 	}
@@ -458,8 +459,8 @@ query_type_rb_toggled_cb (GtkToggleButton *btn, QueryDruid *qdruid)
 /*
  * SELECT query: targets page
  */
-static void select_targets_table_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbTable *table, QueryDruid *qdruid);
-static void select_targets_target_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbTarget *target, QueryDruid *qdruid);
+static void select_targets_table_select_changed_cb (GnomeDbSelector *mgsel, GdaDictTable *table, QueryDruid *qdruid);
+static void select_targets_target_select_changed_cb (GnomeDbSelector *mgsel, GdaQueryTarget *target, QueryDruid *qdruid);
 static void select_targets_add_table (GtkButton *button, QueryDruid *qdruid);
 static void select_targets_up_target (GtkButton *button, QueryDruid *qdruid);
 static void select_targets_dn_target (GtkButton *button, QueryDruid *qdruid);
@@ -594,13 +595,13 @@ make_select_targets_page (QueryDruid *qdruid)
 }
 
 static void
-select_targets_table_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbTable *table, QueryDruid *qdruid)
+select_targets_table_select_changed_cb (GnomeDbSelector *mgsel, GdaDictTable *table, QueryDruid *qdruid)
 {
 	gtk_widget_set_sensitive (qdruid->priv->target_add_button, table ? TRUE : FALSE);
 }
 
 static void
-select_targets_target_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbTarget *target, QueryDruid *qdruid)
+select_targets_target_select_changed_cb (GnomeDbSelector *mgsel, GdaQueryTarget *target, QueryDruid *qdruid)
 {
 	/* gtk_widget_set_sensitive (qdruid->priv->target_up_button, target ? TRUE : FALSE); */
 	/* gtk_widget_set_sensitive (qdruid->priv->target_dn_button, target ? TRUE : FALSE); */
@@ -610,53 +611,56 @@ select_targets_target_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbTarget *
 static void
 select_targets_add_table (GtkButton *button, QueryDruid *qdruid)
 {
-	GnomeDbTarget *target;
-	GnomeDbTable *table;
+	GdaQueryTarget *target;
+	GdaDictTable *table;
 	GSList *constraints, *list;
-	GSList *targets = gnome_db_query_get_targets (qdruid->priv->build_query), *tlist;
+	GSList *targets = gda_query_get_targets (qdruid->priv->build_query), *tlist;
 
 	/* actual target creation */
-	table = (GnomeDbTable *) 
+	table = (GdaDictTable *) 
 		gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->target_tables_selector));
-	g_assert (table && IS_GNOME_DB_TABLE (table));
+	g_assert (table && GDA_IS_DICT_TABLE (table));
 
-	target = GNOME_DB_TARGET (gnome_db_target_new_with_entity (qdruid->priv->build_query, GNOME_DB_ENTITY (table)));
-	gnome_db_query_add_target (qdruid->priv->build_query, target, NULL);
+	target = (GdaQueryTarget*) g_object_new (GDA_TYPE_QUERY_TARGET,
+						 "dict", gda_object_get_dict ((GdaObject*) qdruid->priv->build_query),
+						 "query", qdruid->priv->build_query,
+						 "entity", GDA_ENTITY (table), NULL);
+	gda_query_add_target (qdruid->priv->build_query, target, NULL);
 	g_object_unref (target);
 
 	/* using database FK constraints to create joins */
-	constraints = gnome_db_database_get_tables_fk_constraints (gnome_db_dict_get_database (qdruid->priv->dict),
+	constraints = gda_dict_database_get_tables_fk_constraints (gda_dict_get_database (qdruid->priv->dict),
 							     table, NULL, FALSE);
 	list = constraints;
 	while (list) {
-		GnomeDbConstraint *cons = GNOME_DB_CONSTRAINT (list->data);
-		GnomeDbTable *otable;
-		GnomeDbTarget *otarget = NULL;
+		GdaDictConstraint *cons = GDA_DICT_CONSTRAINT (list->data);
+		GdaDictTable *otable;
+		GdaQueryTarget *otarget = NULL;
 		gboolean table_is_pkey = TRUE;
 
-		otable = gnome_db_constraint_get_table (cons);
+		otable = gda_dict_constraint_get_table (cons);
 		if (otable == table) {
 			table_is_pkey = FALSE;
-			otable = gnome_db_constraint_fkey_get_ref_table (cons);
+			otable = gda_dict_constraint_fkey_get_ref_table (cons);
 		}
 		
 		/* find a suitable target to make a join with */
 		tlist = targets;
 		while (tlist && !otarget) {
-			if (gnome_db_target_get_represented_entity (GNOME_DB_TARGET (tlist->data)) == 
-			    (GnomeDbEntity *) otable)
-				otarget = GNOME_DB_TARGET (tlist->data);
+			if (gda_query_target_get_represented_entity (GDA_QUERY_TARGET (tlist->data)) == 
+			    (GdaEntity *) otable)
+				otarget = GDA_QUERY_TARGET (tlist->data);
 			tlist = g_slist_next (tlist);
 		}
 
 		if (otarget) {
-			GnomeDbJoin *join;
+			GdaQueryJoin *join;
 
 			/* actual join */
-			join = GNOME_DB_JOIN (gnome_db_join_new_with_targets (qdruid->priv->build_query, otarget, target));
-			gnome_db_join_set_join_type (join, GNOME_DB_JOIN_TYPE_INNER);
-			gnome_db_join_set_condition_from_fkcons (join);
-			gnome_db_query_add_join (qdruid->priv->build_query, join);
+			join = GDA_QUERY_JOIN (gda_query_join_new_with_targets (qdruid->priv->build_query, otarget, target));
+			gda_query_join_set_join_type (join, GDA_QUERY_JOIN_TYPE_INNER);
+			gda_query_join_set_condition_from_fkcons (join);
+			gda_query_add_join (qdruid->priv->build_query, join);
 			g_object_unref (join);
 		}
 
@@ -666,7 +670,7 @@ select_targets_add_table (GtkButton *button, QueryDruid *qdruid)
 	g_slist_free (targets);
 
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (qdruid->priv->build_query), 0);
+	gda_object_dump (GDA_OBJECT (qdruid->priv->build_query), 0);
 #endif
 }
 
@@ -685,13 +689,13 @@ select_targets_dn_target (GtkButton *button, QueryDruid *qdruid)
 static void
 select_targets_del_target (GtkButton *button, QueryDruid *qdruid)
 {
-	GnomeDbTarget *target;
+	GdaQueryTarget *target;
 	
-	target = (GnomeDbTarget *)
+	target = (GdaQueryTarget *)
 		gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->target_targets_selector));
-	gnome_db_query_del_target (qdruid->priv->build_query, target);
+	gda_query_del_target (qdruid->priv->build_query, target);
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (qdruid->priv->build_query), 0);
+	gda_object_dump (GDA_OBJECT (qdruid->priv->build_query), 0);
 #endif
 }
 
@@ -699,7 +703,7 @@ static void
 make_select_joins_page (QueryDruid *qdruid)
 {
 	GtkWidget *wid, *vbox, *label;
-	GnomeDbGraph *graph;
+	GdaGraph *graph;
 	gchar *str;
 
 	wid = gnome_druid_page_standard_new ();
@@ -722,7 +726,7 @@ make_select_joins_page (QueryDruid *qdruid)
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
-	graph = GNOME_DB_GRAPH (gnome_db_graph_query_new (qdruid->priv->build_query));
+	graph = GDA_GRAPH (gda_graph_query_new (qdruid->priv->build_query));
 	wid = gnome_db_canvas_query_struct_new (qdruid->priv->build_query, graph);
 	gnome_db_canvas_set_zoom_factor (GNOME_DB_CANVAS (wid), 0.8);
 	g_object_unref (graph);
@@ -731,8 +735,8 @@ make_select_joins_page (QueryDruid *qdruid)
 	gtk_box_pack_start (GTK_BOX (vbox), wid, TRUE, TRUE, 0);
 }
 
-static void select_fields_tfield_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbField *field, QueryDruid *qdruid);
-static void select_fields_qfield_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbQfield *field, QueryDruid *qdruid);
+static void select_fields_tfield_select_changed_cb (GnomeDbSelector *mgsel, GdaEntityField *field, QueryDruid *qdruid);
+static void select_fields_qfield_select_changed_cb (GnomeDbSelector *mgsel, GdaQueryField *field, QueryDruid *qdruid);
 static void select_fields_add_field (GtkButton *button, QueryDruid *qdruid);
 static void select_fields_add_expr (GtkButton *button, QueryDruid *qdruid);
 static void select_fields_up_field (GtkButton *button, QueryDruid *qdruid);
@@ -829,7 +833,7 @@ make_select_fields_page (QueryDruid *qdruid)
 	gtk_widget_show (bbox);
 	gtk_table_attach (GTK_TABLE (table), bbox, 1, 2, 3, 4,
 			  (GtkAttachOptions) (0),
-			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+			  (GtkAttachOptions) (0), 0, 0);
 	
 	button = gtk_button_new ();
 	gtk_widget_show (button);
@@ -904,21 +908,21 @@ make_select_fields_page (QueryDruid *qdruid)
 }
 
 static void
-select_fields_tfield_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbField *field, QueryDruid *qdruid)
+select_fields_tfield_select_changed_cb (GnomeDbSelector *mgsel, GdaEntityField *field, QueryDruid *qdruid)
 {
-	gtk_widget_set_sensitive (qdruid->priv->field_add_button, field && IS_GNOME_DB_FIELD (field) ? TRUE : FALSE);
+	gtk_widget_set_sensitive (qdruid->priv->field_add_button, field && GDA_IS_ENTITY_FIELD (field) ? TRUE : FALSE);
 }
 
 static void
-select_fields_qfield_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbQfield *field, QueryDruid *qdruid)
+select_fields_qfield_select_changed_cb (GnomeDbSelector *mgsel, GdaQueryField *field, QueryDruid *qdruid)
 {
 	gboolean sensitive = FALSE, candn = FALSE;
 
-	if (field && IS_GNOME_DB_FIELD (field))
+	if (field && GDA_IS_ENTITY_FIELD (field))
 		sensitive = TRUE;
 
 	if (sensitive) {
-		GSList *fields = gnome_db_entity_get_fields (GNOME_DB_ENTITY (qdruid->priv->build_query));
+		GSList *fields = gda_entity_get_fields (GDA_ENTITY (qdruid->priv->build_query));
 		GSList *last = g_slist_last (fields);
 		candn = TRUE;
 		if (last && (last->data == (gpointer) field))
@@ -927,7 +931,7 @@ select_fields_qfield_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbQfield *f
 	}
 	gtk_widget_set_sensitive (qdruid->priv->field_up_button, 
 				  sensitive && 
-				  (gnome_db_entity_get_field_index (GNOME_DB_ENTITY (qdruid->priv->build_query), GNOME_DB_FIELD (field)) != 0));
+				  (gda_entity_get_field_index (GDA_ENTITY (qdruid->priv->build_query), GDA_ENTITY_FIELD (field)) != 0));
 	gtk_widget_set_sensitive (qdruid->priv->field_dn_button, candn);
 	gtk_widget_set_sensitive (qdruid->priv->field_del_button, sensitive);
 }
@@ -935,22 +939,26 @@ select_fields_qfield_select_changed_cb (GnomeDbSelector *mgsel, GnomeDbQfield *f
 static void
 select_fields_add_field (GtkButton *button, QueryDruid *qdruid)
 {
-	GnomeDbField *field;
-	GnomeDbTarget *target;
-	GnomeDbQfield *newfield;
+	GdaEntityField *field;
+	GdaQueryTarget *target;
+	GdaQueryField *newfield;
 
-	field = (GnomeDbField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_targets_selector));
-	target = (GnomeDbTarget *) gnome_db_selector_get_selected_object_parent (GNOME_DB_SELECTOR (qdruid->priv->fields_targets_selector));
+	field = (GdaEntityField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_targets_selector));
+	target = (GdaQueryTarget *) gnome_db_selector_get_selected_object_parent (GNOME_DB_SELECTOR (qdruid->priv->fields_targets_selector));
 
-	g_assert (field && IS_GNOME_DB_FIELD (field));
-	g_assert (target && IS_GNOME_DB_TARGET (target));
+	g_assert (field && GDA_IS_ENTITY_FIELD (field));
+	g_assert (target && GDA_IS_QUERY_TARGET (target));
 
-	newfield = GNOME_DB_QFIELD (gnome_db_qf_field_new_with_objects (qdruid->priv->build_query, target, field));
-	gnome_db_base_set_name (GNOME_DB_BASE (newfield), gnome_db_base_get_name (GNOME_DB_BASE (field)));
-	gnome_db_entity_add_field (GNOME_DB_ENTITY (qdruid->priv->build_query), GNOME_DB_FIELD (newfield));
+	newfield = (GdaQueryField*) g_object_new (GDA_TYPE_QUERY_FIELD_FIELD,
+						  "dict", gda_object_get_dict ((GdaObject*) qdruid->priv->build_query),
+						  "query", qdruid->priv->build_query,
+						  "target", target,
+						  "field", field, NULL);
+	gda_object_set_name (GDA_OBJECT (newfield), gda_object_get_name (GDA_OBJECT (field)));
+	gda_entity_add_field (GDA_ENTITY (qdruid->priv->build_query), GDA_ENTITY_FIELD (newfield));
 	g_object_unref (newfield);
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (qdruid->priv->build_query), 0);
+	gda_object_dump (GDA_OBJECT (qdruid->priv->build_query), 0);
 #endif
 }
 
@@ -962,7 +970,7 @@ select_fields_add_expr (GtkButton *button, QueryDruid *qdruid)
 	gchar *msg;
 
 	str = gtk_entry_get_text (GTK_ENTRY (qdruid->priv->expr_entry));
-	if (! gnome_db_query_add_field_from_sql (qdruid->priv->build_query, str, &error)) {
+	if (! gda_query_add_field_from_sql (qdruid->priv->build_query, str, &error)) {
 		GtkWidget *dlg;
 
 		if (error) {
@@ -991,53 +999,53 @@ select_fields_add_expr (GtkButton *button, QueryDruid *qdruid)
 static void
 select_fields_up_field (GtkButton *button, QueryDruid *qdruid)
 {
-	GnomeDbField *field;
+	GdaEntityField *field;
 	gint pos;
 
-	field = (GnomeDbField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
-	g_assert (field && IS_GNOME_DB_FIELD (field));
-	pos = gnome_db_entity_get_field_index (GNOME_DB_ENTITY (qdruid->priv->build_query), field);
+	field = (GdaEntityField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
+	g_assert (field && GDA_IS_ENTITY_FIELD (field));
+	pos = gda_entity_get_field_index (GDA_ENTITY (qdruid->priv->build_query), field);
 	if (pos > 0) {
-		GnomeDbField *ofield;
-		ofield = gnome_db_entity_get_field_by_index (GNOME_DB_ENTITY (qdruid->priv->build_query), pos - 1);
-		gnome_db_entity_swap_fields (GNOME_DB_ENTITY (qdruid->priv->build_query), field, ofield);
+		GdaEntityField *ofield;
+		ofield = gda_entity_get_field_by_index (GDA_ENTITY (qdruid->priv->build_query), pos - 1);
+		gda_entity_swap_fields (GDA_ENTITY (qdruid->priv->build_query), field, ofield);
 	}
 
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (qdruid->priv->build_query), 0);
+	gda_object_dump (GDA_OBJECT (qdruid->priv->build_query), 0);
 #endif
 }
 
 static void
 select_fields_dn_field (GtkButton *button, QueryDruid *qdruid)
 {
-	GnomeDbField *field;
+	GdaEntityField *field;
 	gint pos;
-	GnomeDbField *ofield;
+	GdaEntityField *ofield;
 
-	field = (GnomeDbField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
-	g_assert (field && IS_GNOME_DB_FIELD (field));
-	pos = gnome_db_entity_get_field_index (GNOME_DB_ENTITY (qdruid->priv->build_query), field);
-	ofield = gnome_db_entity_get_field_by_index (GNOME_DB_ENTITY (qdruid->priv->build_query), pos + 1);
+	field = (GdaEntityField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
+	g_assert (field && GDA_IS_ENTITY_FIELD (field));
+	pos = gda_entity_get_field_index (GDA_ENTITY (qdruid->priv->build_query), field);
+	ofield = gda_entity_get_field_by_index (GDA_ENTITY (qdruid->priv->build_query), pos + 1);
 	if (ofield)
-		gnome_db_entity_swap_fields (GNOME_DB_ENTITY (qdruid->priv->build_query), field, ofield);
+		gda_entity_swap_fields (GDA_ENTITY (qdruid->priv->build_query), field, ofield);
 
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (qdruid->priv->build_query), 0);
+	gda_object_dump (GDA_OBJECT (qdruid->priv->build_query), 0);
 #endif
 }
 
 static void
 select_fields_del_field (GtkButton *button, QueryDruid *qdruid)
 {
-	GnomeDbField *field;
+	GdaEntityField *field;
 
-	field = (GnomeDbField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
-	g_assert (field && IS_GNOME_DB_FIELD (field));
-	gnome_db_entity_remove_field (GNOME_DB_ENTITY (qdruid->priv->build_query), field);
+	field = (GdaEntityField *) gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
+	g_assert (field && GDA_IS_ENTITY_FIELD (field));
+	gda_entity_remove_field (GDA_ENTITY (qdruid->priv->build_query), field);
 	
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (qdruid->priv->build_query), 0);
+	gda_object_dump (GDA_OBJECT (qdruid->priv->build_query), 0);
 #endif
 }
 
@@ -1154,15 +1162,15 @@ make_sql_query_page (QueryDruid *qdruid)
 static void
 sql_query_text_changed_cb (GtkButton *button, QueryDruid *qdruid)
 {
-	GnomeDbQuery *query;
+	GdaQuery *query;
 	gchar *sql;
 	GError *error = NULL;
 	gchar *str = NULL;
 	GtkWidget *dlg;
 
 	sql = gnome_db_editor_get_all_text (GNOME_DB_EDITOR (qdruid->priv->sql_editor));
-	query = GNOME_DB_QUERY (gnome_db_query_new_from_sql (qdruid->priv->dict, sql, &error));
-	if (gnome_db_query_get_query_type (query) ==  GNOME_DB_QUERY_TYPE_NON_PARSED_SQL) {
+	query = GDA_QUERY (gda_query_new_from_sql (qdruid->priv->dict, sql, &error));
+	if (gda_query_get_query_type (query) ==  GDA_QUERY_TYPE_NON_PARSED_SQL) {
 		if (error) {
 			str = g_strdup_printf ("<b>%s</b>\n%s", _("Parsing/analyzing error:"), error->message);
 			g_error_free (error);
@@ -1176,7 +1184,7 @@ sql_query_text_changed_cb (GtkButton *button, QueryDruid *qdruid)
 
 	if (str) {
 		dlg = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, "");
+					      GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, " ");
 		gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dlg), str);
 		g_free (str);
 	}
@@ -1242,7 +1250,7 @@ prev_page_cb (GnomeDruidPage *page, GtkWidget *druid, QueryDruid *qdruid)
 
 	/* fields page: if there are less than 2 targets, then skip the joins page */
 	if (page == (GnomeDruidPage *) qdruid->priv->d_select_fields) {
-		GSList *targets = gnome_db_query_get_targets (qdruid->priv->build_query);
+		GSList *targets = gda_query_get_targets (qdruid->priv->build_query);
 		if (g_slist_length (targets) < 2) {
 			gnome_druid_set_page (GNOME_DRUID (qdruid), GNOME_DRUID_PAGE (qdruid->priv->d_select_targets));
 			retval = TRUE;
@@ -1283,7 +1291,10 @@ next_page_cb (GnomeDruidPage *page, GtkWidget *druid, QueryDruid *qdruid)
 	    (page == (GnomeDruidPage *) qdruid->priv->d_select_fields) ||
 	    (page == (GnomeDruidPage *) qdruid->priv->d_select_where))
 		/* nothing to be done here: use the default druid pages order */
-		done = TRUE;
+		    done = TRUE;
+
+	gnome_db_selector_expand_all (GNOME_DB_SELECTOR (qdruid->priv->fields_fields_selector));
+	gnome_db_selector_expand_all (GNOME_DB_SELECTOR (qdruid->priv->fields_targets_selector));
 
 	/* page to select the query type */
 	if (!done && (page == (GnomeDruidPage *) qdruid->priv->d_query_type)) {
@@ -1294,7 +1305,7 @@ next_page_cb (GnomeDruidPage *page, GtkWidget *druid, QueryDruid *qdruid)
 			gnome_druid_set_page (GNOME_DRUID (qdruid), GNOME_DRUID_PAGE (qdruid->priv->d_sql));
 			gnome_druid_set_show_finish (GNOME_DRUID (qdruid), TRUE);
 			break;
-		case GNOME_DB_QUERY_TYPE_SELECT:
+		case GDA_QUERY_TYPE_SELECT:
 			gnome_druid_set_page (GNOME_DRUID (qdruid), GNOME_DRUID_PAGE (qdruid->priv->d_select_targets));
 			gnome_druid_set_show_finish (GNOME_DRUID (qdruid), FALSE);
 			break;			
@@ -1316,7 +1327,7 @@ next_page_cb (GnomeDruidPage *page, GtkWidget *druid, QueryDruid *qdruid)
 
 	/* targets page: if there are less than 2 targets, then skip the joins page */
 	if (page == (GnomeDruidPage *) qdruid->priv->d_select_targets) {
-		GSList *targets = gnome_db_query_get_targets (qdruid->priv->build_query);
+		GSList *targets = gda_query_get_targets (qdruid->priv->build_query);
 		if (g_slist_length (targets) < 2) {
 			gnome_druid_set_page (GNOME_DRUID (qdruid), GNOME_DRUID_PAGE (qdruid->priv->d_select_fields));
 			retval = TRUE;
@@ -1341,24 +1352,24 @@ static void
 finish_page_cb (GnomeDruidPage *page, GtkWidget *druid, QueryDruid *qdruid)
 {
 	gboolean done = FALSE;
-	GnomeDbQuery *created_query = NULL;
+	GdaQuery *created_query = NULL;
 
 	/* page for SQL queries */
 	if (!done && (page == (GnomeDruidPage *) qdruid->priv->d_sql)) {
-		GnomeDbQuery *query;
+		GdaQuery *query;
 		gchar *sql;
 		const gchar *str;
 
 		sql = gnome_db_editor_get_all_text (GNOME_DB_EDITOR (qdruid->priv->sql_editor));
-		query = GNOME_DB_QUERY (gnome_db_query_new_from_sql (qdruid->priv->dict, sql, NULL));
+		query = GDA_QUERY (gda_query_new_from_sql (qdruid->priv->dict, sql, NULL));
 		str = gtk_entry_get_text (GTK_ENTRY (qdruid->priv->query_name));
 		if (str && *str)
-			gnome_db_base_set_name (GNOME_DB_BASE (query), str);
+			gda_object_set_name (GDA_OBJECT (query), str);
 		str = gtk_entry_get_text (GTK_ENTRY (qdruid->priv->query_descr));
 		if (str && *str)
-			gnome_db_base_set_description (GNOME_DB_BASE (query), str);
+			gda_object_set_description (GDA_OBJECT (query), str);
 
-		gnome_db_dict_assume_query (qdruid->priv->dict, query);
+		gda_dict_assume_object (qdruid->priv->dict, (GdaObject *) query);
 		created_query = query;
 		g_object_unref (G_OBJECT (query));
 
@@ -1366,19 +1377,19 @@ finish_page_cb (GnomeDruidPage *page, GtkWidget *druid, QueryDruid *qdruid)
 	}
 
 	if (!done && (page == (GnomeDruidPage *) qdruid->priv->d_select_finish)) {
-		GnomeDbGraph *graph;
-		gnome_db_dict_assume_query (qdruid->priv->dict, qdruid->priv->build_query);
+		GdaGraph *graph;
+		gda_dict_assume_object (qdruid->priv->dict, (GdaObject *) qdruid->priv->build_query);
 		created_query = qdruid->priv->build_query;
 
-		graph = gnome_db_dict_get_graph_for_object (qdruid->priv->dict, G_OBJECT (qdruid->priv->build_query));
-		gnome_db_dict_assume_graph (qdruid->priv->dict, graph);
+		graph = gda_graphs_get_graph_for_object (qdruid->priv->dict, G_OBJECT (qdruid->priv->build_query));
+		gda_dict_assume_object (qdruid->priv->dict, (GdaObject *) graph);
 
 		done = TRUE;
 	}
 
 	if (created_query) {
-		gnome_db_base_set_name (GNOME_DB_BASE (created_query), gtk_entry_get_text (GTK_ENTRY (qdruid->priv->query_name)));
-		gnome_db_base_set_description (GNOME_DB_BASE (created_query), gtk_entry_get_text (GTK_ENTRY (qdruid->priv->query_descr)));
+		gda_object_set_name (GDA_OBJECT (created_query), gtk_entry_get_text (GTK_ENTRY (qdruid->priv->query_name)));
+		gda_object_set_description (GDA_OBJECT (created_query), gtk_entry_get_text (GTK_ENTRY (qdruid->priv->query_descr)));
 	}
 
 	if (!done)
