@@ -1,6 +1,6 @@
 /* query-editor.c
  *
- * Copyright (C) 2004 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,14 +30,14 @@ static void query_editor_dispose (GObject   * object);
 
 struct _QueryEditorPriv
 {
-	GnomeDbQuery     *query;
+	GdaQuery     *query;
 	
 	GtkWidget   *q_name;
 	GtkWidget   *q_descr;
 	GtkWidget   *notebook;
 	GtkWidget   *toggle;
 
-	guint        notebook_trans[GNOME_DB_QUERY_TYPE_NON_PARSED_SQL];
+	guint        notebook_trans[GDA_QUERY_TYPE_NON_PARSED_SQL];
 
 	/* SQL edition */
 	GtkWidget   *sql_editor;   /* GnomeDbEditor */
@@ -90,39 +90,39 @@ query_editor_init (QueryEditor * wid)
 	wid->priv = g_new0 (QueryEditorPriv, 1);
 	wid->priv->query = NULL;
 
-	for (i=0; i<GNOME_DB_QUERY_TYPE_NON_PARSED_SQL; i++)
+	for (i=0; i<GDA_QUERY_TYPE_NON_PARSED_SQL; i++)
 		wid->priv->notebook_trans[i] = 0;
 }
 
 static void query_editor_initialize (QueryEditor *mgsel);
 
 
-static void query_nullified_cb (GnomeDbQuery *query, QueryEditor *mgsel);
+static void query_destroyed_cb (GdaQuery *query, QueryEditor *mgsel);
 static void edition_mode_toggled (GtkToggleButton *button, QueryEditor *qedit);
 
 /**
  * query_editor_new
- * @dict: a #GnomeDbDict object
+ * @dict: a #GdaDict object
  *
  * Creates a new #QueryEditor widget.
  *
  * Returns: the new widget
  */
 GtkWidget *
-query_editor_new (GnomeDbQuery *query)
+query_editor_new (GdaQuery *query)
 {
 	GObject    *obj;
 	QueryEditor *qedit;
 
-	g_return_val_if_fail (query && IS_GNOME_DB_QUERY (query), NULL);
+	g_return_val_if_fail (query && GDA_IS_QUERY (query), NULL);
 		
 	obj = g_object_new (QUERY_EDITOR_TYPE, NULL);
 	qedit = QUERY_EDITOR (obj);
 
 	qedit->priv->query = query;
 
-	gnome_db_base_connect_nullify (qedit->priv->query,
-				 G_CALLBACK (query_nullified_cb), qedit);
+	gda_object_connect_destroy (qedit->priv->query,
+				 G_CALLBACK (query_destroyed_cb), qedit);
 	
 	query_editor_initialize (qedit);
 	edition_mode_toggled (GTK_TOGGLE_BUTTON (qedit->priv->toggle), qedit);
@@ -130,10 +130,10 @@ query_editor_new (GnomeDbQuery *query)
 	return GTK_WIDGET (obj);
 }
 
-static void query_changed_cb (GnomeDbQuery *query, QueryEditor *qedit);
-static void query_type_changed_cb (GnomeDbQuery *query, QueryEditor *qedit);
+static void query_changed_cb (GdaQuery *query, QueryEditor *qedit);
+static void query_type_changed_cb (GdaQuery *query, QueryEditor *qedit);
 static void
-query_nullified_cb (GnomeDbQuery *query, QueryEditor *mgsel)
+query_destroyed_cb (GdaQuery *query, QueryEditor *mgsel)
 {
 	gtk_widget_destroy (GTK_WIDGET (mgsel));
 }
@@ -148,10 +148,10 @@ query_editor_dispose (GObject *object)
 	qedit = QUERY_EDITOR (object);
 
 	if (qedit->priv) {
-		/* Weak unref the GnomeDbQuery if necessary */
+		/* Weak unref the GdaQuery if necessary */
 		if (qedit->priv->query) {
 			g_signal_handlers_disconnect_by_func (G_OBJECT (qedit->priv->query),
-							      G_CALLBACK (query_nullified_cb), qedit);
+							      G_CALLBACK (query_destroyed_cb), qedit);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (qedit->priv->query),
 							      G_CALLBACK (query_changed_cb), qedit);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (qedit->priv->query),
@@ -188,7 +188,7 @@ query_editor_initialize (QueryEditor *qedit)
 {
 	GtkWidget *wid, *label, *table, *hbox, *nb, *vbox, *vp, *vbox2, *exp;
 	GtkWidget *bbox, *button;
-	GnomeDbGraph *graph;
+	GdaGraph *graph;
 	gchar *str;
 
 	gtk_box_set_spacing (GTK_BOX (qedit), 6);
@@ -304,7 +304,7 @@ query_editor_initialize (QueryEditor *qedit)
 	 * Point and click edition page: SELECT queries 
 	 */
 	vbox = gtk_vbox_new (FALSE, 6);
-	qedit->priv->notebook_trans[GNOME_DB_QUERY_TYPE_SELECT] = gtk_notebook_append_page (GTK_NOTEBOOK (nb), 
+	qedit->priv->notebook_trans[GDA_QUERY_TYPE_SELECT] = gtk_notebook_append_page (GTK_NOTEBOOK (nb), 
 										      vbox, NULL);
 	gtk_widget_show (vbox);
 
@@ -335,13 +335,13 @@ query_editor_initialize (QueryEditor *qedit)
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
-	graph = gnome_db_dict_get_graph_for_object (gnome_db_base_get_dict (GNOME_DB_BASE (qedit->priv->query)), 
-					      G_OBJECT (qedit->priv->query));
+	graph = gda_graphs_get_graph_for_object (gda_object_get_dict (GDA_OBJECT (qedit->priv->query)), 
+						 G_OBJECT (qedit->priv->query));
 	if (!graph) {
 		/* the query did not have any graph: create one */
-		graph = GNOME_DB_GRAPH (gnome_db_graph_query_new (qedit->priv->query));
-		gnome_db_graph_query_sync_targets (GNOME_DB_GRAPH_QUERY (graph));
-		gnome_db_dict_assume_graph (gnome_db_base_get_dict (GNOME_DB_BASE (qedit->priv->query)), graph);
+		graph = GDA_GRAPH (gda_graph_query_new (qedit->priv->query));
+		gda_graph_query_sync_targets (GDA_GRAPH_QUERY (graph));
+		gda_dict_assume_object (gda_object_get_dict (GDA_OBJECT (qedit->priv->query)), (GdaObject *) graph);
 		g_object_unref (graph);
 	}
 	wid = gnome_db_canvas_query_struct_new (qedit->priv->query, graph);
@@ -443,7 +443,7 @@ entry_name_changed_cb (GtkEntry *entry, QueryEditor *qedit)
 	/* blocking recursive signal */
 	g_signal_handlers_block_by_func (G_OBJECT (qedit->priv->query),
 					 G_CALLBACK (query_changed_cb), qedit);
-	gnome_db_base_set_name (GNOME_DB_BASE (qedit->priv->query), gtk_entry_get_text (entry));
+	gda_object_set_name (GDA_OBJECT (qedit->priv->query), gtk_entry_get_text (entry));
 	/* unblocking recursive signal */
 	g_signal_handlers_unblock_by_func (G_OBJECT (qedit->priv->query),
 					   G_CALLBACK (query_changed_cb), qedit);
@@ -455,14 +455,14 @@ entry_description_changed_cb (GtkEntry *entry, QueryEditor *qedit)
 	/* blocking recursive signal */
 	g_signal_handlers_block_by_func (G_OBJECT (qedit->priv->query),
 					 G_CALLBACK (query_changed_cb), qedit);
-	gnome_db_base_set_description (GNOME_DB_BASE (qedit->priv->query), gtk_entry_get_text (entry));
+	gda_object_set_description (GDA_OBJECT (qedit->priv->query), gtk_entry_get_text (entry));
 	/* unblocking recursive signal */
 	g_signal_handlers_unblock_by_func (G_OBJECT (qedit->priv->query),
 					   G_CALLBACK (query_changed_cb), qedit);
 }
 
 static void
-query_changed_cb (GnomeDbQuery *query, QueryEditor *qedit)
+query_changed_cb (GdaQuery *query, QueryEditor *qedit)
 {
 	const gchar *str;
 	gchar *sql;
@@ -473,22 +473,22 @@ query_changed_cb (GnomeDbQuery *query, QueryEditor *qedit)
 	g_signal_handlers_block_by_func (G_OBJECT (qedit->priv->q_descr),
 					 G_CALLBACK (entry_description_changed_cb), qedit);
 	/* query name */
-	str = gnome_db_base_get_name (GNOME_DB_BASE (qedit->priv->query));
+	str = gda_object_get_name (GDA_OBJECT (qedit->priv->query));
 	if (str)
 		gtk_entry_set_text (GTK_ENTRY (qedit->priv->q_name), str);
 	else
 		gtk_entry_set_text (GTK_ENTRY (qedit->priv->q_name), "");
 	
 	/* query description */
-	str = gnome_db_base_get_description (GNOME_DB_BASE (qedit->priv->query));
+	str = gda_object_get_description (GDA_OBJECT (qedit->priv->query));
 	if (str)
 		gtk_entry_set_text (GTK_ENTRY (qedit->priv->q_descr), str);
 	else
 		gtk_entry_set_text (GTK_ENTRY (qedit->priv->q_descr), "");
 
 	/* SQL version */
-	sql = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (qedit->priv->query), NULL, 
-					 GNOME_DB_RENDERER_EXTRA_PRETTY_SQL | GNOME_DB_RENDERER_EXTRA_VAL_ATTRS, NULL);
+	sql = gda_renderer_render_as_sql (GDA_RENDERER (qedit->priv->query), NULL, 
+					 GDA_RENDERER_EXTRA_PRETTY_SQL | GDA_RENDERER_EXTRA_VAL_ATTRS, NULL);
 	if (sql) {
 		gnome_db_editor_set_text (GNOME_DB_EDITOR (qedit->priv->sql_editor), sql, -1);
 		g_free (sql);
@@ -498,12 +498,12 @@ query_changed_cb (GnomeDbQuery *query, QueryEditor *qedit)
 
 	/* Global WHERE condition */
 	if (qedit->priv->select_where) {
-		GnomeDbCondition *cond = gnome_db_query_get_condition (qedit->priv->query);
+		GdaQueryCondition *cond = gda_query_get_condition (qedit->priv->query);
 		sql = NULL;
 
 		if (cond) 
-			sql = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (cond), NULL, 
-							 GNOME_DB_RENDERER_EXTRA_PRETTY_SQL | GNOME_DB_RENDERER_EXTRA_VAL_ATTRS, NULL);
+			sql = gda_renderer_render_as_sql (GDA_RENDERER (cond), NULL, 
+							 GDA_RENDERER_EXTRA_PRETTY_SQL | GDA_RENDERER_EXTRA_VAL_ATTRS, NULL);
 		if (sql) {
 			gnome_db_editor_set_text (GNOME_DB_EDITOR (qedit->priv->select_where), sql, -1);
 			g_free (sql);
@@ -526,17 +526,17 @@ sql_query_text_apply_cb (GtkButton *button, QueryEditor *qedit)
 	gchar *sql;
 	GError *error = NULL;
 	gchar *str = NULL;
-	GnomeDbQuery *query = qedit->priv->query;
-	GnomeDbQuery *tmpquery;
+	GdaQuery *query = qedit->priv->query;
+	GdaQuery *tmpquery;
 	gboolean do_apply = FALSE;
 
 	/* test the new SQL on a temporary query, to be able to let the user change his mind and
 	 * refuse to apply the new SQL text */
 	sql = gnome_db_editor_get_all_text (GNOME_DB_EDITOR (qedit->priv->sql_editor));
-	tmpquery = GNOME_DB_QUERY (gnome_db_query_new_copy (query, NULL));
-	gnome_db_query_set_sql_text (tmpquery, sql, &error);
+	tmpquery = GDA_QUERY (gda_query_new_copy (query, NULL));
+	gda_query_set_sql_text (tmpquery, sql, &error);
 
-	if (gnome_db_query_get_query_type (tmpquery) ==  GNOME_DB_QUERY_TYPE_NON_PARSED_SQL) {
+	if (gda_query_get_query_type (tmpquery) ==  GDA_QUERY_TYPE_NON_PARSED_SQL) {
 		if (error) {
 			str = g_strdup (error->message);
 			g_error_free (error);
@@ -556,8 +556,8 @@ sql_query_text_apply_cb (GtkButton *button, QueryEditor *qedit)
 				       _("This prevents extra treatments, such as graphical edition of this query, "
 					 "which will be considered as a SQL statement specific to the "
 					 "connected database."), str,
-				       _("Do you still want to use that SQL for the query ?"));
-		window = gtk_widget_get_toplevel (button);
+				       _("Do you still want to use that SQL for the query?"));
+		window = gtk_widget_get_toplevel ((GtkWidget *) button);
 		if (GTK_WIDGET_TOPLEVEL (window))
 			window = NULL;
 		dlg = gtk_message_dialog_new ((GtkWindow*) window, GTK_DIALOG_MODAL, 
@@ -575,12 +575,12 @@ sql_query_text_apply_cb (GtkButton *button, QueryEditor *qedit)
 	g_object_unref (tmpquery);
 	if (do_apply)
 		/* really apply the new text */
-		gnome_db_query_set_sql_text (query, sql, NULL);
+		gda_query_set_sql_text (query, sql, NULL);
 	g_free (sql);
 }
 
 static void
-query_type_changed_cb (GnomeDbQuery *query, QueryEditor *qedit)
+query_type_changed_cb (GdaQuery *query, QueryEditor *qedit)
 {
 	edition_mode_toggled (GTK_TOGGLE_BUTTON (qedit->priv->toggle), qedit);
 }
@@ -588,9 +588,9 @@ query_type_changed_cb (GnomeDbQuery *query, QueryEditor *qedit)
 static void
 edition_mode_toggled (GtkToggleButton *button, QueryEditor *qedit)
 {
-	GnomeDbQueryType qtype = gnome_db_query_get_query_type (qedit->priv->query);
+	GdaQueryType qtype = gda_query_get_query_type (qedit->priv->query);
 
-	if (qtype == GNOME_DB_QUERY_TYPE_NON_PARSED_SQL) 
+	if (qtype == GDA_QUERY_TYPE_NON_PARSED_SQL) 
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (qedit->priv->notebook), 0);
 	else 
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (qedit->priv->notebook),
@@ -601,23 +601,23 @@ edition_mode_toggled (GtkToggleButton *button, QueryEditor *qedit)
 static void
 select_where_apply_cb (GtkButton *button, QueryEditor *qedit)
 {
-	GnomeDbCondition *cond;
+	GdaQueryCondition *cond;
 	gchar *sql;
 	GError *error = NULL;
 
 	sql = gnome_db_editor_get_all_text (GNOME_DB_EDITOR (qedit->priv->select_where));
 	if (!sql || !(*sql)) {
-		gnome_db_query_set_condition (qedit->priv->query, NULL);
+		gda_query_set_condition (qedit->priv->query, NULL);
 		g_free (sql);
 		return;
 	}
 
-	cond = (GnomeDbCondition *) gnome_db_condition_new_from_sql (qedit->priv->query, sql, NULL, &error);
+	cond = (GdaQueryCondition *) gda_query_condition_new_from_sql (qedit->priv->query, sql, NULL, &error);
 	if (cond) {
-		gnome_db_query_set_condition (qedit->priv->query, cond);
+		gda_query_set_condition (qedit->priv->query, cond);
 		g_object_unref (cond);
 #ifdef debug_NO
-		gnome_db_base_dump (GNOME_DB_BASE (qedit->priv->query), 10);
+		gda_object_dump (GDA_OBJECT (qedit->priv->query), 10);
 #endif
 
 	}
