@@ -1,6 +1,6 @@
 /* ws-datatypes.c
  *
- * Copyright (C) 2004 - 2005 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,6 +24,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <libgnomedb/libgnomedb.h>
+#include <glib/gi18n-lib.h>
 
 /* 
  * Main static functions 
@@ -47,7 +48,7 @@ static GObjectClass  *parent_class = NULL;
 /* private structure */
 struct _WsDatatypesPrivate
 {
-	GnomeDbDict    *dict;
+	GdaDict        *dict;
 	GtkWidget      *selector;
 	GtkWidget      *work_area;
 
@@ -121,19 +122,19 @@ static void ws_datatypes_initialize (WsDatatypes *ws);
 
 /**
  * ws_datatypes_new
- * @dict: a #GnomeDbDict object
+ * @dict: a #GdaDict object
  *
  * Creates a new WsDatatypes object
  *
  * Returns: the new object
  */
 GObject*
-ws_datatypes_new (GnomeDbDict *dict)
+ws_datatypes_new (GdaDict *dict)
 {
 	GObject  *obj;
 	WsDatatypes *ws;
 
-	g_return_val_if_fail (dict && IS_GNOME_DB_DICT (dict), NULL);
+	g_return_val_if_fail (dict && GDA_IS_DICT (dict), NULL);
 
 	obj = g_object_new (WS_DATATYPES_TYPE, NULL);
 	ws = WS_DATATYPES (obj);
@@ -198,7 +199,7 @@ ws_datatypes_finalize (GObject   * object)
 
 static void selector_selection_changed_cb (GnomeDbSelector *mgsel, GObject *sel_object, WsDatatypes *ws);
 static void dtypes_filter_mode_changed_cb (GtkWidget *wid, WsDatatypes *ws);
-static void dtype_updated_cb (GnomeDbServer *srv, GnomeDbServerDataType *dtype, WsDatatypes *ws);
+static void dtype_updated_cb (GdaConnection *srv, GdaDictType *dtype, WsDatatypes *ws);
 static void
 ws_datatypes_initialize (WsDatatypes *ws)
 {
@@ -343,20 +344,20 @@ ws_datatypes_initialize (WsDatatypes *ws)
 	gtk_text_buffer_create_tag (ws->priv->textbuffer, "descr",
 				    "style", PANGO_STYLE_ITALIC, NULL);
 	
-	g_signal_connect (G_OBJECT (gnome_db_dict_get_server (ws->priv->dict)), "data_type_updated",
+	g_signal_connect (G_OBJECT (ws->priv->dict), "object_updated",
 			  G_CALLBACK (dtype_updated_cb), ws);
 }
 
-static void dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws);
+static void dtype_info_display_update (GdaDictType *dtype, WsDatatypes *ws);
 static void
 selector_selection_changed_cb (GnomeDbSelector *mgsel, GObject *sel_object, WsDatatypes *ws)
 {
-	if (sel_object && !IS_GNOME_DB_SERVER_DATA_TYPE (sel_object))
+	if (sel_object && !GDA_IS_DICT_TYPE (sel_object))
 		return;
 	
 	ws->priv->sel_obj = sel_object;
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (ws->priv->notebook), sel_object ? 1 : 0);
-	dtype_info_display_update ((GnomeDbServerDataType*) sel_object, ws);
+	dtype_info_display_update ((GdaDictType*) sel_object, ws);
 }
 
 static void 
@@ -373,23 +374,23 @@ dtypes_filter_mode_changed_cb (GtkWidget *wid, WsDatatypes *ws)
 }
 
 static void
-dtype_updated_cb (GnomeDbServer *srv, GnomeDbServerDataType *dtype, WsDatatypes *ws)
+dtype_updated_cb (GdaConnection *srv, GdaDictType *dtype, WsDatatypes *ws)
 {
-	if ((GObject *)dtype == ws->priv->sel_obj)
+	if (GDA_IS_DICT_TYPE (dtype) && ((GObject *)dtype == ws->priv->sel_obj))
 		dtype_info_display_update (dtype, ws);
 }
 
-static gchar *function_get_args (GnomeDbServerFunction *func);
+static gchar *function_get_args (GdaDictFunction *func);
 static void
-dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws)
+dtype_info_display_update (GdaDictType *dtype, WsDatatypes *ws)
 {
 	GtkTextIter start, end;
-	const gchar *str = NULL;
+	gchar *str = NULL;
 	gchar *title = NULL;
 
 	/* description */
 	if (dtype)
-		str = gnome_db_base_get_description (GNOME_DB_BASE (dtype));
+		str = (gchar *) gda_object_get_description (GDA_OBJECT (dtype));
 	
 	if (str && *str) 
 		gtk_label_set_text (GTK_LABEL (ws->priv->description), str);
@@ -399,7 +400,7 @@ dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws)
 	/* synonyms */
 	str = NULL;
 	if (dtype) {
-		GSList *synlist = gnome_db_server_data_type_get_synonyms (dtype);
+		const GSList *synlist = gda_dict_type_get_synonyms (dtype);
 		if (synlist) {
 			GString *string;
 
@@ -433,24 +434,24 @@ dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws)
 	if (dtype) {
 		GSList *list, *funcs, *args, *aggs;
 		gboolean getfunc;
-		GnomeDbServerDataType *ldt;
+		GdaDictType *ldt;
 		
-		funcs = gnome_db_server_get_functions (gnome_db_dict_get_server (ws->priv->dict));
-		aggs = gnome_db_server_get_aggregates (gnome_db_dict_get_server (ws->priv->dict));
+		funcs = gda_dict_get_functions (ws->priv->dict);
+		aggs = gda_dict_get_aggregates (ws->priv->dict);
 		list = g_slist_concat (funcs, aggs);
 		funcs = list;
 		while (list) {
 			getfunc = FALSE;
 			switch (ws->priv->filter_mode) {
 			case 0:
-				if (IS_GNOME_DB_SERVER_FUNCTION (list->data)) {
-					ldt = gnome_db_server_function_get_ret_type (GNOME_DB_SERVER_FUNCTION (list->data));
+				if (GDA_IS_DICT_FUNCTION (list->data)) {
+					ldt = gda_dict_function_get_ret_type (GDA_DICT_FUNCTION (list->data));
 					getfunc = (ldt == dtype) ? TRUE : FALSE;
 				}
 				break;
 			case 1:
-				if (IS_GNOME_DB_SERVER_FUNCTION (list->data)) {
-					args = gnome_db_server_function_get_arg_types (GNOME_DB_SERVER_FUNCTION (list->data));
+				if (GDA_IS_DICT_FUNCTION (list->data)) {
+					args = (GSList *) gda_dict_function_get_arg_types (GDA_DICT_FUNCTION (list->data));
 					while (args && !getfunc) {
 						if ((args->data == (gpointer) dtype) || !args->data)
 							getfunc = TRUE;
@@ -459,8 +460,8 @@ dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws)
 				}
 				break;
 			case 2:
-				if (IS_GNOME_DB_SERVER_AGGREGATE (list->data)) {
-					ldt = gnome_db_server_aggregate_get_arg_type (GNOME_DB_SERVER_AGGREGATE (list->data));
+				if (GDA_IS_DICT_AGGREGATE (list->data)) {
+					ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data));
 					getfunc = !ldt || (ldt == dtype) ? TRUE : FALSE;
 				}
 				break;
@@ -469,17 +470,17 @@ dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws)
 			if (getfunc) {
 				gchar *str;
 
-				str = gnome_db_base_get_name (GNOME_DB_BASE (list->data));
+				str = (gchar *) gda_object_get_name (GDA_OBJECT (list->data));
 				gtk_text_buffer_get_end_iter (ws->priv->textbuffer, &end);
 				gtk_text_buffer_insert_with_tags_by_name (ws->priv->textbuffer, 
 									  &end, str, -1, 
 									  "funcname", NULL);
 
-				if (IS_GNOME_DB_SERVER_FUNCTION (list->data))
-					str = function_get_args (GNOME_DB_SERVER_FUNCTION (list->data));
+				if (GDA_IS_DICT_FUNCTION (list->data))
+					str = function_get_args (GDA_DICT_FUNCTION (list->data));
 				else {
-					if ((ldt = gnome_db_server_aggregate_get_arg_type (GNOME_DB_SERVER_AGGREGATE (list->data)))) {
-						str = g_strdup_printf (" (%s)", gnome_db_base_get_name (GNOME_DB_BASE (ldt)));
+					if ((ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data)))) {
+						str = g_strdup_printf (" (%s)", gda_object_get_name (GDA_OBJECT (ldt)));
 					}
 					else
 						str = g_strdup (" (*)");
@@ -488,7 +489,7 @@ dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws)
 				gtk_text_buffer_insert (ws->priv->textbuffer, &end, str, -1);
 				g_free (str);
 
-				str = gnome_db_base_get_description (GNOME_DB_BASE (list->data));
+				str = (gchar *) gda_object_get_description (GDA_OBJECT (list->data));
 				if (str && *str) {
 					gchar *str2 = g_strdup_printf (" -- %s\n", str);
 					gtk_text_buffer_get_end_iter (ws->priv->textbuffer, &end);
@@ -508,7 +509,7 @@ dtype_info_display_update (GnomeDbServerDataType *dtype, WsDatatypes *ws)
 }
 
 static gchar *
-function_get_args (GnomeDbServerFunction *func)
+function_get_args (GdaDictFunction *func)
 {
 	GString *string;
 	const GSList *args;
@@ -516,7 +517,7 @@ function_get_args (GnomeDbServerFunction *func)
 	gboolean firstarg = TRUE;
 
 	string = g_string_new ("");
-	args = gnome_db_server_function_get_arg_types (func);
+	args = gda_dict_function_get_arg_types (func);
 	g_string_append (string, " (");
 	while (args) {
 		if (firstarg)
@@ -525,7 +526,7 @@ function_get_args (GnomeDbServerFunction *func)
 			g_string_append (string, ", ");
 		if (args->data) 
 			g_string_append (string,
-					 gnome_db_server_data_type_get_sqlname (GNOME_DB_SERVER_DATA_TYPE (args->data)));
+					 gda_dict_type_get_sqlname (GDA_DICT_TYPE (args->data)));
 		else
 			g_string_append (string, "*");
 		args = g_slist_next (args);
@@ -562,7 +563,7 @@ ws_datatypes_get_description (WorkspacePage *iface)
 	ws = WS_DATATYPES (iface);
 	if (ws->priv->sel_obj) {
 		const gchar *cstr;
-		 cstr =  gnome_db_base_get_name (GNOME_DB_BASE (ws->priv->sel_obj));
+		 cstr =  gda_object_get_name (GDA_OBJECT (ws->priv->sel_obj));
 		 str = g_strdup_printf ("Data type: <b>%s</b>", (cstr && *cstr) ? cstr : "---");
 	}
 	else
